@@ -14,15 +14,16 @@
 static GWENHYWFAR_CB
 int Gtk3Gui_WDialog_SetIntProperty(GWEN_WIDGET *w,
                                    GWEN_DIALOG_PROPERTY prop,
-                                   int index,
+                                   GWEN_UNUSED int index,
                                    int value,
-                                   int doSignal) {
+                                   GWEN_UNUSED int doSignal)
+{
   GtkWindow *g;
 
   g=GTK_WINDOW(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     gtk_widget_set_sensitive(GTK_WIDGET(g), (value==0)?FALSE:TRUE);
     return 0;
@@ -63,14 +64,15 @@ int Gtk3Gui_WDialog_SetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk3Gui_WDialog_GetIntProperty(GWEN_WIDGET *w,
                                    GWEN_DIALOG_PROPERTY prop,
-                                   int index,
-                                   int defaultValue) {
+                                   GWEN_UNUSED int index,
+                                   int defaultValue)
+{
   GtkWindow *g;
 
   g=GTK_WINDOW(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     return (gtk_widget_get_sensitive(GTK_WIDGET(g))==TRUE)?1:0;
 
@@ -107,15 +109,16 @@ int Gtk3Gui_WDialog_GetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk3Gui_WDialog_SetCharProperty(GWEN_WIDGET *w,
                                     GWEN_DIALOG_PROPERTY prop,
-                                    int index,
+                                    GWEN_UNUSED int index,
                                     const char *value,
-                                    int doSignal) {
+                                    GWEN_UNUSED int doSignal)
+{
   GtkWindow *g;
 
   g=GTK_WINDOW(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Title:
     gtk_window_set_title(GTK_WINDOW(g), value);
     return 0;
@@ -132,16 +135,17 @@ int Gtk3Gui_WDialog_SetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-const char* Gtk3Gui_WDialog_GetCharProperty(GWEN_WIDGET *w,
-    GWEN_DIALOG_PROPERTY prop,
-    int index,
-    const char *defaultValue) {
+const char *Gtk3Gui_WDialog_GetCharProperty(GWEN_WIDGET *w,
+                                            GWEN_DIALOG_PROPERTY prop,
+                                            GWEN_UNUSED int index,
+                                            const char *defaultValue)
+{
   GtkWindow *g;
 
   g=GTK_WINDOW(GWEN_Widget_GetImplData(w, GTK3_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Title:
     return gtk_window_get_title(GTK_WINDOW(g));
   default:
@@ -157,7 +161,8 @@ const char* Gtk3Gui_WDialog_GetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-int Gtk3Gui_WDialog_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild) {
+int Gtk3Gui_WDialog_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild)
+{
   GtkWidget *g;
   GtkWidget *gChild;
 
@@ -174,12 +179,11 @@ int Gtk3Gui_WDialog_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild) {
 
 
 
-int Gtk3Gui_WDialog_Setup(GWEN_WIDGET *w) {
+int Gtk3Gui_WDialog_Setup(GWEN_WIDGET *w)
+{
   GtkWidget *g;
   const char *s;
-  uint32_t flags;
 
-  flags=GWEN_Widget_GetFlags(w);
   s=GWEN_Widget_GetText(w, 0);
 
   g=gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -187,8 +191,8 @@ int Gtk3Gui_WDialog_Setup(GWEN_WIDGET *w) {
   if (s && *s)
     gtk_window_set_title(GTK_WINDOW(g), s);
 
-  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_REAL, (void*) g);
-  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_CONTENT, (void*) g);
+  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_REAL, (void *) g);
+  GWEN_Widget_SetImplData(w, GTK3_DIALOG_WIDGET_CONTENT, (void *) g);
 
   GWEN_Widget_SetSetIntPropertyFn(w, Gtk3Gui_WDialog_SetIntProperty);
   GWEN_Widget_SetGetIntPropertyFn(w, Gtk3Gui_WDialog_GetIntProperty);
