@@ -31,6 +31,7 @@
 #endif
 
 #include "args_p.h"
+#include "gui_l.h"
 #include <gwenhywfar/misc.h>
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/text.h>
@@ -45,26 +46,35 @@ int GWEN_Args_Check(int argc, char **argv,
                     int startAt,
                     uint32_t mode,
                     const GWEN_ARGS *args,
-                    GWEN_DB_NODE *db){
+                    GWEN_DB_NODE *db)
+{
   int i;
   const char *p;
   const GWEN_ARGS *tmpArgs;
   GWEN_DB_NODE *counts;
+  GWEN_BUFFER *tbuf;
   int stop;
 
   i=startAt;
 
+  tbuf=GWEN_Buffer_new(0, 256, 0, 1);
   counts=GWEN_DB_Group_new("counts");
 
   stop=0;
-  while(i<argc && !stop) {
+  while (i<argc && !stop) {
     GWEN_ARGS_ELEMENT_TYPE t;
     char *tmpBuf;
     const char *v;
     int value;
 
     DBG_INFO(GWEN_LOGDOMAIN, "Argument[%d] is \"%s\"", i, argv[i]);
-    p=argv[i];
+    if (GWEN_Gui_ReadString(argv[i], tbuf)) {
+      DBG_ERROR(GWEN_LOGDOMAIN, "Error parsing \"%s\"", argv[i]);
+      GWEN_DB_Group_free(counts);
+      GWEN_Buffer_free(tbuf);
+      return GWEN_ARGS_RESULT_ERROR;
+    }
+    p=GWEN_Buffer_GetStart(tbuf);
     if (*p=='-') {
       p++;
       if (*p=='-') {
@@ -77,7 +87,7 @@ int GWEN_Args_Check(int argc, char **argv,
     else
       t=GWEN_ArgsElementTypeFreeParam;
 
-    switch(t) {
+    switch (t) {
     case GWEN_ArgsElementTypeFreeParam:
       if (mode & GWEN_ARGS_MODE_ALLOW_FREEPARAM) {
         GWEN_DB_SetCharValue(db,
@@ -88,6 +98,7 @@ int GWEN_Args_Check(int argc, char **argv,
       else {
         DBG_ERROR(GWEN_LOGDOMAIN, "Only options are allowed, but argument \"%s\" was not recognized as a known option.", p);
         GWEN_DB_Group_free(counts);
+        GWEN_Buffer_free(tbuf);
         return GWEN_ARGS_RESULT_ERROR;
       }
       if (mode & GWEN_ARGS_MODE_STOP_AT_FREEPARAM) {
@@ -97,7 +108,7 @@ int GWEN_Args_Check(int argc, char **argv,
       break;
 
     case GWEN_ArgsElementTypeShort:
-      for(tmpArgs=args;;tmpArgs++) {
+      for (tmpArgs=args;; tmpArgs++) {
         if (tmpArgs->shortOption) {
           if (strcmp(tmpArgs->shortOption, p)==0) {
             /* found option */
@@ -112,6 +123,7 @@ int GWEN_Args_Check(int argc, char **argv,
         if (tmpArgs->flags & GWEN_ARGS_FLAGS_LAST) {
           DBG_ERROR(GWEN_LOGDOMAIN, "Unknown short option \"%s\"", p);
           GWEN_DB_Group_free(counts);
+          GWEN_Buffer_free(tbuf);
           return GWEN_ARGS_RESULT_ERROR;
         }
       } /* for */
@@ -122,19 +134,30 @@ int GWEN_Args_Check(int argc, char **argv,
         if (i>=argc) {
           DBG_ERROR(GWEN_LOGDOMAIN, "Argument needed for option \"%s\"", tmpArgs->name);
           GWEN_DB_Group_free(counts);
+          GWEN_Buffer_free(tbuf);
           return GWEN_ARGS_RESULT_ERROR;
         }
-        switch(tmpArgs->type) {
+        GWEN_Buffer_Reset(tbuf);
+        if (GWEN_Gui_ReadString(argv[i], tbuf)) {
+          DBG_ERROR(GWEN_LOGDOMAIN, "Error parsing \"%s\"", argv[i]);
+          GWEN_DB_Group_free(counts);
+          GWEN_Buffer_free(tbuf);
+          return GWEN_ARGS_RESULT_ERROR;
+        }
+        p=GWEN_Buffer_GetStart(tbuf);
+        switch (tmpArgs->type) {
         case GWEN_ArgsType_Char:
           GWEN_DB_SetCharValue(db,
                                GWEN_DB_FLAGS_DEFAULT,
-                               tmpArgs->name, argv[i]);
+                               tmpArgs->name, p);
           break;
 
         case GWEN_ArgsType_Int:
-          if (sscanf(argv[i], "%i", &value)!=1) {
-            DBG_ERROR(GWEN_LOGDOMAIN, "Non-integer argument for short option \"%s\"", p);
+          if (sscanf(p, "%i", &value)!=1) {
+            DBG_ERROR(GWEN_LOGDOMAIN, "Non-integer argument for short option \"%s\"",
+                      tmpArgs->shortOption);
             GWEN_DB_Group_free(counts);
+            GWEN_Buffer_free(tbuf);
             return GWEN_ARGS_RESULT_ERROR;
           }
           GWEN_DB_SetIntValue(db,
@@ -146,19 +169,21 @@ int GWEN_Args_Check(int argc, char **argv,
           DBG_ERROR(GWEN_LOGDOMAIN, "Unknown option type \"%d\"",
                     tmpArgs->type);
           GWEN_DB_Group_free(counts);
+          GWEN_Buffer_free(tbuf);
           return GWEN_ARGS_RESULT_ERROR;
         } /* switch */
         i++;
       }
       else {
-	if (tmpArgs->flags & GWEN_ARGS_FLAGS_HELP) {
-	  GWEN_DB_Group_free(counts);
-	  return GWEN_ARGS_RESULT_HELP;
-	}
-	GWEN_DB_SetIntValue(db,
-			    GWEN_DB_FLAGS_OVERWRITE_VARS,
-			    tmpArgs->name,
-			    GWEN_DB_GetIntValue(counts, tmpArgs->name, 0, 0));
+        if (tmpArgs->flags & GWEN_ARGS_FLAGS_HELP) {
+          GWEN_DB_Group_free(counts);
+          GWEN_Buffer_free(tbuf);
+          return GWEN_ARGS_RESULT_HELP;
+        }
+        GWEN_DB_SetIntValue(db,
+                            GWEN_DB_FLAGS_OVERWRITE_VARS,
+                            tmpArgs->name,
+                            GWEN_DB_GetIntValue(counts, tmpArgs->name, 0, 0));
       }
       break;
 
@@ -166,13 +191,14 @@ int GWEN_Args_Check(int argc, char **argv,
       /* copy option name up to (but excluding) the "=" if any,
        * determine the start of possible argument */
       v=p;
-      while(*v && *v!='=') v++;
-      tmpBuf=(char*)malloc(v-p+1);
+      while (*v && *v!='=')
+        v++;
+      tmpBuf=(char *)malloc(v-p+1);
       assert(tmpBuf);
       memmove(tmpBuf, p, v-p);
       tmpBuf[v-p]=0;
 
-      for(tmpArgs=args;;tmpArgs++) {
+      for (tmpArgs=args;; tmpArgs++) {
         if (tmpArgs->longOption) {
           if (strcmp(tmpArgs->longOption, tmpBuf)==0) {
             /* found option */
@@ -188,6 +214,7 @@ int GWEN_Args_Check(int argc, char **argv,
           DBG_ERROR(GWEN_LOGDOMAIN, "Unknown long option \"%s\"", tmpBuf);
           free(tmpBuf);
           GWEN_DB_Group_free(counts);
+          GWEN_Buffer_free(tbuf);
           return GWEN_ARGS_RESULT_ERROR;
         }
       } /* for */
@@ -199,6 +226,7 @@ int GWEN_Args_Check(int argc, char **argv,
                     tmpArgs->name);
           free(tmpBuf);
           GWEN_DB_Group_free(counts);
+          GWEN_Buffer_free(tbuf);
           return GWEN_ARGS_RESULT_ERROR;
         }
         v++;
@@ -210,9 +238,10 @@ int GWEN_Args_Check(int argc, char **argv,
           DBG_ERROR(GWEN_LOGDOMAIN, "Argument needed for option \"%s\"", tmpArgs->name);
           free(tmpBuf);
           GWEN_DB_Group_free(counts);
+          GWEN_Buffer_free(tbuf);
           return GWEN_ARGS_RESULT_ERROR;
         }
-        switch(tmpArgs->type) {
+        switch (tmpArgs->type) {
         case GWEN_ArgsType_Char:
           GWEN_DB_SetCharValue(db,
                                GWEN_DB_FLAGS_DEFAULT,
@@ -225,6 +254,7 @@ int GWEN_Args_Check(int argc, char **argv,
                       tmpBuf);
             free(tmpBuf);
             GWEN_DB_Group_free(counts);
+            GWEN_Buffer_free(tbuf);
             return GWEN_ARGS_RESULT_ERROR;
           }
           GWEN_DB_SetIntValue(db,
@@ -234,16 +264,20 @@ int GWEN_Args_Check(int argc, char **argv,
 
         default:
           DBG_ERROR(GWEN_LOGDOMAIN, "Unknown option type \"%d\"", tmpArgs->type);
+          free(tmpBuf);
           GWEN_DB_Group_free(counts);
+          GWEN_Buffer_free(tbuf);
           return GWEN_ARGS_RESULT_ERROR;
         } /* switch */
       }
       else {
-	if (tmpArgs->flags & GWEN_ARGS_FLAGS_HELP) {
-	  GWEN_DB_Group_free(counts);
-	  return GWEN_ARGS_RESULT_HELP;
-	}
-	GWEN_DB_SetIntValue(db,
+        if (tmpArgs->flags & GWEN_ARGS_FLAGS_HELP) {
+          free(tmpBuf);
+          GWEN_DB_Group_free(counts);
+          GWEN_Buffer_free(tbuf);
+          return GWEN_ARGS_RESULT_HELP;
+        }
+        GWEN_DB_SetIntValue(db,
                             GWEN_DB_FLAGS_OVERWRITE_VARS,
                             tmpArgs->name,
                             GWEN_DB_GetIntValue(counts, tmpArgs->name, 0, 0));
@@ -256,13 +290,15 @@ int GWEN_Args_Check(int argc, char **argv,
       DBG_ERROR(GWEN_LOGDOMAIN, "Internal error (unknown argv type \"%d\")",
                 t);
       GWEN_DB_Group_free(counts);
+      GWEN_Buffer_free(tbuf);
       return GWEN_ARGS_RESULT_ERROR;
       break;
     } /* switch */
+    GWEN_Buffer_Reset(tbuf);
   } /* while */
 
   /* check argument counts */
-  for(tmpArgs=args;;tmpArgs++) {
+  for (tmpArgs=args;; tmpArgs++) {
     const char *s;
     int c;
 
@@ -283,6 +319,7 @@ int GWEN_Args_Check(int argc, char **argv,
         DBG_ERROR(GWEN_LOGDOMAIN, "Option \"%s\" needed", s);
       }
       GWEN_DB_Group_free(counts);
+      GWEN_Buffer_free(tbuf);
       return GWEN_ARGS_RESULT_ERROR;
     }
 
@@ -292,6 +329,7 @@ int GWEN_Args_Check(int argc, char **argv,
                 "Option \"%s\" needed at most %d times (have %d)",
                 s, tmpArgs->maxNum, c);
       GWEN_DB_Group_free(counts);
+      GWEN_Buffer_free(tbuf);
       return GWEN_ARGS_RESULT_ERROR;
     }
 
@@ -299,17 +337,20 @@ int GWEN_Args_Check(int argc, char **argv,
       break;
   } /* for */
   GWEN_DB_Group_free(counts);
+  GWEN_Buffer_free(tbuf);
 
   return i;
 }
 
 
-int GWEN_Args__AppendTXT(GWEN_BUFFER *ubuf, const char *s, unsigned int ins){
+int GWEN_Args__AppendTXT(GWEN_BUFFER *ubuf, const char *s, unsigned int ins)
+{
   unsigned int i;
 
-  while(*s) {
-    for (i=0; i<ins; i++) GWEN_Buffer_AppendByte(ubuf, ' ');
-    while(*s) {
+  while (*s) {
+    for (i=0; i<ins; i++)
+      GWEN_Buffer_AppendByte(ubuf, ' ');
+    while (*s) {
       char c;
 
       c=*s;
@@ -325,10 +366,11 @@ int GWEN_Args__AppendTXT(GWEN_BUFFER *ubuf, const char *s, unsigned int ins){
 
 
 
-int GWEN_Args_UsageTXT(const GWEN_ARGS *args, GWEN_BUFFER *ubuf){
+int GWEN_Args_UsageTXT(const GWEN_ARGS *args, GWEN_BUFFER *ubuf)
+{
   const GWEN_ARGS *tmpArgs;
 
-  for(tmpArgs=args;;tmpArgs++) {
+  for (tmpArgs=args;; tmpArgs++) {
     const char *s;
 
     GWEN_Buffer_AppendString(ubuf, "\n");
@@ -389,17 +431,19 @@ int GWEN_Args_UsageTXT(const GWEN_ARGS *args, GWEN_BUFFER *ubuf){
 
 
 int GWEN_Args_UsageHTML(GWEN_UNUSED const GWEN_ARGS *args,
-			GWEN_UNUSED GWEN_BUFFER *ubuf){
+                        GWEN_UNUSED GWEN_BUFFER *ubuf)
+{
   return 0;
 }
 
 
 
 int GWEN_Args_Usage(const GWEN_ARGS *args, GWEN_BUFFER *ubuf,
-                    GWEN_ARGS_OUTTYPE ot){
+                    GWEN_ARGS_OUTTYPE ot)
+{
   int rv;
 
-  switch(ot) {
+  switch (ot) {
   case GWEN_ArgsOutType_Txt:
     rv=GWEN_Args_UsageTXT(args, ubuf);
     break;
@@ -417,8 +461,9 @@ int GWEN_Args_Usage(const GWEN_ARGS *args, GWEN_BUFFER *ubuf,
 
 
 int GWEN_Args_ShortUsage(GWEN_UNUSED const GWEN_ARGS *args,
-			 GWEN_UNUSED GWEN_BUFFER *ubuf,
-                         GWEN_UNUSED GWEN_ARGS_OUTTYPE ot){
+                         GWEN_UNUSED GWEN_BUFFER *ubuf,
+                         GWEN_UNUSED GWEN_ARGS_OUTTYPE ot)
+{
   return 0;
 }
 
