@@ -56,7 +56,8 @@ static GWEN_LOGGER_DOMAIN *gwen_loggerdomains=0;
 
 
 
-int GWEN_Logger_ModuleInit(){
+int GWEN_Logger_ModuleInit(void)
+{
   const char *s;
   GWEN_LOGGER_LEVEL ll=GWEN_LoggerLevel_Warning;
 
@@ -77,10 +78,11 @@ int GWEN_Logger_ModuleInit(){
 
 
 
-int GWEN_Logger_ModuleFini(){
+int GWEN_Logger_ModuleFini(void)
+{
   GWEN_LOGGER_DOMAIN *ld;
 
-  while((ld=gwen_loggerdomains)) {
+  while ((ld=gwen_loggerdomains)) {
     GWEN_LoggerDomain_Del(ld);
     GWEN_LoggerDomain_free(ld);
   }
@@ -89,7 +91,8 @@ int GWEN_Logger_ModuleFini(){
 
 
 
-GWEN_LOGGER_DOMAIN *GWEN_LoggerDomain_new(const char *name){
+GWEN_LOGGER_DOMAIN *GWEN_LoggerDomain_new(const char *name)
+{
   GWEN_LOGGER_DOMAIN *ld;
 
   assert(name);
@@ -100,7 +103,8 @@ GWEN_LOGGER_DOMAIN *GWEN_LoggerDomain_new(const char *name){
 
 
 
-void GWEN_LoggerDomain_free(GWEN_LOGGER_DOMAIN *ld){
+void GWEN_LoggerDomain_free(GWEN_LOGGER_DOMAIN *ld)
+{
   if (ld) {
     free(ld->name);
     GWEN_Logger_free(ld->logger);
@@ -109,12 +113,13 @@ void GWEN_LoggerDomain_free(GWEN_LOGGER_DOMAIN *ld){
 }
 
 
-GWEN_LOGGER_DOMAIN *GWEN_LoggerDomain_Find(const char *name) {
+GWEN_LOGGER_DOMAIN *GWEN_LoggerDomain_Find(const char *name)
+{
   GWEN_LOGGER_DOMAIN *ld;
 
   assert(name);
   ld=gwen_loggerdomains;
-  while(ld) {
+  while (ld) {
     if (strcasecmp(ld->name, name)==0)
       break;
     ld=ld->next;
@@ -125,21 +130,24 @@ GWEN_LOGGER_DOMAIN *GWEN_LoggerDomain_Find(const char *name) {
 
 
 
-void GWEN_LoggerDomain_Add(GWEN_LOGGER_DOMAIN *ld){
+void GWEN_LoggerDomain_Add(GWEN_LOGGER_DOMAIN *ld)
+{
   assert(ld);
   GWEN_LIST_INSERT(GWEN_LOGGER_DOMAIN, ld, &gwen_loggerdomains);
 }
 
 
 
-void GWEN_LoggerDomain_Del(GWEN_LOGGER_DOMAIN *ld){
+void GWEN_LoggerDomain_Del(GWEN_LOGGER_DOMAIN *ld)
+{
   assert(ld);
   GWEN_LIST_DEL(GWEN_LOGGER_DOMAIN, ld, &gwen_loggerdomains);
 }
 
 
 
-GWEN_LOGGER *GWEN_LoggerDomain_GetLogger(const char *name) {
+GWEN_LOGGER *GWEN_LoggerDomain_GetLogger(const char *name)
+{
   GWEN_LOGGER_DOMAIN *ld;
 
   if (!name)
@@ -158,7 +166,8 @@ GWEN_LOGGER *GWEN_LoggerDomain_GetLogger(const char *name) {
 
 
 
-GWEN_LOGGER *GWEN_Logger_new(GWEN_LOGGER_DOMAIN *domain){
+GWEN_LOGGER *GWEN_Logger_new(GWEN_LOGGER_DOMAIN *domain)
+{
   GWEN_LOGGER *lg;
 
   GWEN_NEW_OBJECT(GWEN_LOGGER, lg);
@@ -172,7 +181,8 @@ GWEN_LOGGER *GWEN_Logger_new(GWEN_LOGGER_DOMAIN *domain){
 
 
 
-void GWEN_Logger_free(GWEN_LOGGER *lg){
+void GWEN_Logger_free(GWEN_LOGGER *lg)
+{
   if (lg) {
     assert(lg->usage);
     if (--(lg->usage)==0) {
@@ -185,14 +195,16 @@ void GWEN_Logger_free(GWEN_LOGGER *lg){
 
 
 
-void GWEN_Logger_Attach(GWEN_LOGGER *lg){
+void GWEN_Logger_Attach(GWEN_LOGGER *lg)
+{
   assert(lg);
   lg->usage++;
 }
 
 
 
-void GWEN_Logger_AddLogger(GWEN_LOGGER *oldLogger, GWEN_LOGGER *newLogger){
+void GWEN_Logger_AddLogger(GWEN_LOGGER *oldLogger, GWEN_LOGGER *newLogger)
+{
   assert(newLogger);
 
   assert(oldLogger);
@@ -201,9 +213,12 @@ void GWEN_Logger_AddLogger(GWEN_LOGGER *oldLogger, GWEN_LOGGER *newLogger){
 
 
 
-void GWEN_Logger_SetDefaultLogger(GWEN_UNUSED GWEN_LOGGER *lg){
+#ifndef NO_DEPRECATED_SYMBOLS
+void GWEN_Logger_SetDefaultLogger(GWEN_UNUSED GWEN_LOGGER *lg)
+{
   fprintf(stderr, "GWEN_Logger_SetDefaultLogger: Deprecated function\n");
 }
+#endif // ifndef NO_DEPRECATED_SYMBOLS
 
 
 
@@ -211,7 +226,8 @@ int GWEN_Logger_Open(const char *logDomain,
                      const char *ident,
                      const char *file,
                      GWEN_LOGGER_LOGTYPE logtype,
-                     GWEN_LOGGER_FACILITY facility){
+                     GWEN_LOGGER_FACILITY facility)
+{
   GWEN_LOGGER *lg;
 
   lg=GWEN_LoggerDomain_GetLogger(logDomain);
@@ -226,7 +242,7 @@ int GWEN_Logger_Open(const char *logDomain,
     if (file==0) {
       lg->logType=GWEN_LoggerType_Console;
       lg->enabled=1;
-      fprintf(stderr,"LOGGER: No filename given, will log to console.\n");
+      fprintf(stderr, "LOGGER: No filename given, will log to console.\n");
     }
     else {
       lg->logType=GWEN_LoggerType_File;
@@ -238,7 +254,7 @@ int GWEN_Logger_Open(const char *logDomain,
     /* caller wants to log via syslog */
     int fac;
 
-    switch(facility) {
+    switch (facility) {
     case GWEN_LoggerFacility_Auth:
       fac=LOG_AUTH;
       break;
@@ -259,9 +275,9 @@ int GWEN_Logger_Open(const char *logDomain,
     }
 
     openlog(ident,
-	    LOG_CONS |
-	    LOG_PID,
-	    fac);
+            LOG_CONS |
+            LOG_PID,
+            fac);
     lg->enabled=1;
   } /* if syslog */
 #endif /* ifdef HAVE_SYSLOG_H */
@@ -273,12 +289,14 @@ int GWEN_Logger_Open(const char *logDomain,
 
   lg->open=1;
 
-  return GWEN_Logger_Log(logDomain, GWEN_LoggerLevel_Debug, "started");
+  GWEN_Logger_Log(logDomain, GWEN_LoggerLevel_Debug, "started");
+  return 0;
 }
 
 
 
-void GWEN_Logger_Close(const char *logDomain){
+void GWEN_Logger_Close(const char *logDomain)
+{
   GWEN_LOGGER *lg;
 
   lg=GWEN_LoggerDomain_GetLogger(logDomain);
@@ -297,7 +315,8 @@ void GWEN_Logger_Close(const char *logDomain){
 
 
 
-int GWEN_Logger_IsOpen(const char *logDomain){
+int GWEN_Logger_IsOpen(const char *logDomain)
+{
   GWEN_LOGGER_DOMAIN *ld;
 
   if (!logDomain)
@@ -311,7 +330,8 @@ int GWEN_Logger_IsOpen(const char *logDomain){
 
 int GWEN_Logger__CreateMessage(GWEN_LOGGER *lg,
                                GWEN_LOGGER_LEVEL priority, const char *s,
-                               GWEN_BUFFER *mbuf) {
+                               GWEN_BUFFER *mbuf)
+{
 #ifdef HAVE_SNPRINTF
   unsigned int i;
 #endif /* HAVE_SNPRINTF */
@@ -324,7 +344,7 @@ int GWEN_Logger__CreateMessage(GWEN_LOGGER *lg,
   assert(lg);
   if (lg->logIdent) {
     if (strlen(lg->logIdent)+32>=sizeof(buffer)) {
-      fprintf(stderr," LOGGER: Logbuffer too small (1).\n");
+      fprintf(stderr, " LOGGER: Logbuffer too small (1).\n");
       return 1;
     }
   }
@@ -336,31 +356,31 @@ int GWEN_Logger__CreateMessage(GWEN_LOGGER *lg,
 # ifdef HAVE_SNPRINTF
 #  ifdef HAVE_GETPID
   i=snprintf(buffer, sizeof(buffer)-1,
-             "%d:%04d/%02d/%02d %02d-%02d-%02d:%s(%d):",priority,
-	     t->tm_year+1900, t->tm_mon+1, t->tm_mday,
-	     t->tm_hour, t->tm_min, t->tm_sec,
+             "%d:%04d/%02d/%02d %02d-%02d-%02d:%s(%d):", priority,
+             t->tm_year+1900, t->tm_mon+1, t->tm_mday,
+             t->tm_hour, t->tm_min, t->tm_sec,
              lg->logIdent, (int)getpid());
 #  else
   i=snprintf(buffer, sizeof(buffer)-1,
-	     "%d:%04d/%02d/%02d %02d-%02d-%02d:%s:",priority,
-	     t->tm_year+1900, t->tm_mon+1, t->tm_mday,
-	     t->tm_hour, t->tm_min, t->tm_sec,
+             "%d:%04d/%02d/%02d %02d-%02d-%02d:%s:", priority,
+             t->tm_year+1900, t->tm_mon+1, t->tm_mday,
+             t->tm_hour, t->tm_min, t->tm_sec,
              lg->logIdent);
 #  endif /* HAVE_GETPID */
   if (i>=sizeof(buffer)) {
-    fprintf(stderr," LOGGER: Logbuffer too small (2).\n");
+    fprintf(stderr, " LOGGER: Logbuffer too small (2).\n");
     return 1;
   }
 # else   /* HAVE_SNPRINTF */
 #  ifdef HAVE_GETPID
-  sprintf(buffer,"%d:%04d/%02d/%02d %02d-%02d-%02d:%s(%d):",priority,
+  sprintf(buffer, "%d:%04d/%02d/%02d %02d-%02d-%02d:%s(%d):", priority,
           t->tm_year+1900, t->tm_mon+1, t->tm_mday,
           t->tm_hour, t->tm_min, t->tm_sec,
           lg->logIdent, (int)getpid());
 #  else
-  sprintf(buffer,"%d:%04d/%02d/%02d %02d-%02d-%02d:%s:",priority,
-	  t->tm_year+1900, t->tm_mon+1, t->tm_mday,
-	  t->tm_hour, t->tm_min, t->tm_sec,
+  sprintf(buffer, "%d:%04d/%02d/%02d %02d-%02d-%02d:%s:", priority,
+          t->tm_year+1900, t->tm_mon+1, t->tm_mday,
+          t->tm_hour, t->tm_min, t->tm_sec,
           lg->logIdent);
 #  endif /* HAVE_GETPID */
 # endif  /* HAVE_SNPRINTF */
@@ -368,14 +388,14 @@ int GWEN_Logger__CreateMessage(GWEN_LOGGER *lg,
 # ifdef HAVE_SNPRINTF
   buffer[sizeof(buffer)-1]=0;
   i=snprintf(buffer, sizeof(buffer)-1,
-             "%d:%s:",priority,
-	     lg->logIdent);
+             "%d:%s:", priority,
+             lg->logIdent);
   if (i>=sizeof(buffer)) {
-    fprintf(stderr," LOGGER: Logbuffer too small (3).\n");
+    fprintf(stderr, " LOGGER: Logbuffer too small (3).\n");
     return 1;
   }
 # else   /* HAVE_SNPRINTF */
-  sprintf(buffer,"%d:%s:",priority,
+  sprintf(buffer, "%d:%s:", priority,
           lg->logIdent);
 # endif  /* HAVE_SNPRINTF */
 #endif   /* HAVE_TIME_H */
@@ -388,8 +408,9 @@ int GWEN_Logger__CreateMessage(GWEN_LOGGER *lg,
 
 
 int GWEN_Logger_CreateLogMessage(const char *logDomain,
-				 GWEN_LOGGER_LEVEL priority, const char *s,
-				 GWEN_BUFFER *mbuf){
+                                 GWEN_LOGGER_LEVEL priority, const char *s,
+                                 GWEN_BUFFER *mbuf)
+{
   GWEN_LOGGER *lg;
 
   lg=GWEN_LoggerDomain_GetLogger(logDomain);
@@ -401,8 +422,9 @@ int GWEN_Logger_CreateLogMessage(const char *logDomain,
 
 
 int GWEN_Logger__Log(GWEN_LOGGER *lg,
-                     GWEN_LOGGER_LEVEL priority, const char *s){
-  while(lg) {
+                     GWEN_LOGGER_LEVEL priority, const char *s)
+{
+  while (lg) {
     FILE *f;
 #ifdef HAVE_SYSLOG_H
     int pri;
@@ -416,7 +438,7 @@ int GWEN_Logger__Log(GWEN_LOGGER *lg,
       return 0;
 
     mbuf=GWEN_Buffer_new(0, 256, 0, 1);
-    switch(lg->logType) {
+    switch (lg->logType) {
     case GWEN_LoggerType_File:
       rv=GWEN_Logger__CreateMessage(lg, priority, s, mbuf);
       if (rv) {
@@ -424,7 +446,7 @@ int GWEN_Logger__Log(GWEN_LOGGER *lg,
         return rv;
       }
 
-      f=fopen(lg->logFile,"a+");
+      f=fopen(lg->logFile, "a+");
       if (f==0) {
         fprintf(stderr,
                 "LOGGER: Unable to open file \"%s\" (%s)\n",
@@ -459,7 +481,7 @@ int GWEN_Logger__Log(GWEN_LOGGER *lg,
 
 #ifdef HAVE_SYSLOG_H
     case GWEN_LoggerType_Syslog:
-      switch(priority) {
+      switch (priority) {
       case GWEN_LoggerLevel_Emergency:
         pri=LOG_EMERG;
         break;
@@ -489,7 +511,7 @@ int GWEN_Logger__Log(GWEN_LOGGER *lg,
         pri=LOG_DEBUG;
         break;
       } /* switch */
-      syslog(pri,"%s",s);
+      syslog(pri, "%s", s);
       break;
 #endif /* HAVE_SYSLOG_H */
 
@@ -528,58 +550,60 @@ int GWEN_Logger__Log(GWEN_LOGGER *lg,
 
 
 
-int GWEN_Logger_Log(const char *logDomain,
-                    GWEN_LOGGER_LEVEL priority, const char *s){
+void GWEN_Logger_Log(const char *logDomain,
+                     GWEN_LOGGER_LEVEL priority, const char *s)
+{
   if (!GWEN_Gui_LogHook(logDomain, priority, s)) {
     const char *p;
-    int rv;
+    /*int rv;*/
     unsigned int i;
     GWEN_BUFFER *mbuf;
     GWEN_LOGGER *lg;
-  
+
     lg=GWEN_LoggerDomain_GetLogger(logDomain);
     assert(lg);
-  
+
     if (!lg->enabled)
-      return 1;
-  
+      return /*1*/;
+
     if (priority>lg->logLevel)
       /* priority too low, don't log */
-      return 0;
-  
+      return /*0*/;
+
     /* temporarily disable logging to avoid endless loops */
     lg->enabled=0;
     /* copy buffer, exchange all newlines by 0 */
     mbuf=GWEN_Buffer_new(0, strlen(s)+1, 0, 1);
     for (i=0; i<strlen(s)+1; i++) {
       if (s[i]=='\n') {
-	GWEN_Buffer_AppendByte(mbuf, 0);
+        GWEN_Buffer_AppendByte(mbuf, 0);
       }
       else
-	GWEN_Buffer_AppendByte(mbuf, s[i]);
+        GWEN_Buffer_AppendByte(mbuf, s[i]);
     }
-  
+
     /* now log each line */
-    rv=0;
+    /*rv=0;*/
     p=GWEN_Buffer_GetStart(mbuf);
     while (*p) {
-      rv|=GWEN_Logger__Log(lg, priority, p);
-      while(*p)
-	p++;
+      GWEN_Logger__Log(lg, priority, p);
+      while (*p)
+        p++;
       p++;
     }
     GWEN_Buffer_free(mbuf);
     /* reenable logging */
     lg->enabled=1;
-    return rv;
+    return /*rv*/;
   }
   else
-    return 0;
+    return /*0*/;
 }
 
 
 
-void GWEN_Logger_Enable(const char *logDomain, int f){
+void GWEN_Logger_Enable(const char *logDomain, int f)
+{
   GWEN_LOGGER *lg;
 
   lg=GWEN_LoggerDomain_GetLogger(logDomain);
@@ -589,7 +613,8 @@ void GWEN_Logger_Enable(const char *logDomain, int f){
 
 
 
-int GWEN_Logger_IsEnabled(const char *logDomain){
+int GWEN_Logger_IsEnabled(const char *logDomain)
+{
   GWEN_LOGGER *lg;
 
   lg=GWEN_LoggerDomain_GetLogger(logDomain);
@@ -599,7 +624,8 @@ int GWEN_Logger_IsEnabled(const char *logDomain){
 
 
 
-void GWEN_Logger_SetLevel(const char *logDomain, GWEN_LOGGER_LEVEL l){
+void GWEN_Logger_SetLevel(const char *logDomain, GWEN_LOGGER_LEVEL l)
+{
   GWEN_LOGGER *lg;
 
   lg=GWEN_LoggerDomain_GetLogger(logDomain);
@@ -609,7 +635,8 @@ void GWEN_Logger_SetLevel(const char *logDomain, GWEN_LOGGER_LEVEL l){
 
 
 
-int GWEN_Logger_GetLevel(const char *logDomain) {
+int GWEN_Logger_GetLevel(const char *logDomain)
+{
   GWEN_LOGGER *lg;
 
   lg=GWEN_LoggerDomain_GetLogger(logDomain);
@@ -620,7 +647,8 @@ int GWEN_Logger_GetLevel(const char *logDomain) {
 
 
 
-void GWEN_Logger_SetIdent(const char *logDomain, const char *id){
+void GWEN_Logger_SetIdent(const char *logDomain, const char *id)
+{
   GWEN_LOGGER *lg;
 
   lg=GWEN_LoggerDomain_GetLogger(logDomain);
@@ -635,7 +663,8 @@ void GWEN_Logger_SetIdent(const char *logDomain, const char *id){
 
 
 
-void GWEN_Logger_SetFilename(const char *logDomain, const char *name){
+void GWEN_Logger_SetFilename(const char *logDomain, const char *name)
+{
   GWEN_LOGGER *lg;
 
   lg=GWEN_LoggerDomain_GetLogger(logDomain);
@@ -651,7 +680,8 @@ void GWEN_Logger_SetFilename(const char *logDomain, const char *name){
 
 
 GWEN_LOGGERFUNCTIONLOG GWEN_Logger_SetLogFunction(const char *logDomain,
-						  GWEN_LOGGERFUNCTIONLOG fn){
+                                                  GWEN_LOGGERFUNCTIONLOG fn)
+{
   GWEN_LOGGER *lg;
   GWEN_LOGGERFUNCTIONLOG oldFn;
 
@@ -664,7 +694,8 @@ GWEN_LOGGERFUNCTIONLOG GWEN_Logger_SetLogFunction(const char *logDomain,
 
 
 
-GWEN_LOGGER_LEVEL GWEN_Logger_Name2Level(const char *name) {
+GWEN_LOGGER_LEVEL GWEN_Logger_Name2Level(const char *name)
+{
   if (strcasecmp(name, "emergency")==0)
     return GWEN_LoggerLevel_Emergency;
   else if (strcasecmp(name, "alert")==0)
@@ -681,7 +712,7 @@ GWEN_LOGGER_LEVEL GWEN_Logger_Name2Level(const char *name) {
     return GWEN_LoggerLevel_Info;
   else if (strcasecmp(name, "debug")==0)
     return GWEN_LoggerLevel_Debug;
-  else if (strcasecmp(name, "verbous")==0)
+  else if (strcasecmp(name, "verbous")==0 || strcasecmp(name, "verbose")==0)
     return GWEN_LoggerLevel_Verbous;
   else {
     return GWEN_LoggerLevel_Unknown;
@@ -690,38 +721,51 @@ GWEN_LOGGER_LEVEL GWEN_Logger_Name2Level(const char *name) {
 
 
 
-const char *GWEN_Logger_Level2Name(GWEN_LOGGER_LEVEL level) {
+const char *GWEN_Logger_Level2Name(GWEN_LOGGER_LEVEL level)
+{
   const char *s;
 
-  switch(level) {
+  switch (level) {
   case GWEN_LoggerLevel_Emergency:
-    s="emergency"; break;
+    s="emergency";
+    break;
   case GWEN_LoggerLevel_Alert:
-    s="alert"; break;
+    s="alert";
+    break;
   case GWEN_LoggerLevel_Critical:
-    s="critical"; break;
+    s="critical";
+    break;
   case GWEN_LoggerLevel_Error:
-    s="error"; break;
+    s="error";
+    break;
   case GWEN_LoggerLevel_Warning:
-    s="warning"; break;
+    s="warning";
+    break;
   case GWEN_LoggerLevel_Notice:
-    s="notice"; break;
+    s="notice";
+    break;
   case GWEN_LoggerLevel_Info:
-    s="info"; break;
+    s="info";
+    break;
   case GWEN_LoggerLevel_Debug:
-    s="debug"; break;
+    s="debug";
+    break;
   case GWEN_LoggerLevel_Verbous:
-    s="verbous"; break;
+    /* yes, we know the spelling is wrong. But it's a historic bug, fixing it would make Gwen incompatible with previous versions. */
+    s="verbous";
+    break;
   case GWEN_LoggerLevel_Unknown:
   default:
-    s="unknown"; break;
+    s="unknown";
+    break;
   } /* switch */
   return s;
 }
 
 
 
-GWEN_LOGGER_LOGTYPE GWEN_Logger_Name2Logtype(const char *name) {
+GWEN_LOGGER_LOGTYPE GWEN_Logger_Name2Logtype(const char *name)
+{
   if (strcasecmp(name, "console")==0)
     return GWEN_LoggerType_Console;
   else if (strcasecmp(name, "file")==0)
@@ -737,28 +781,35 @@ GWEN_LOGGER_LOGTYPE GWEN_Logger_Name2Logtype(const char *name) {
 
 
 
-const char *GWEN_Logger_Logtype2Name(GWEN_LOGGER_LOGTYPE lt) {
+const char *GWEN_Logger_Logtype2Name(GWEN_LOGGER_LOGTYPE lt)
+{
   const char *s;
 
-  switch(lt) {
+  switch (lt) {
   case GWEN_LoggerType_Console:
-    s="console"; break;
+    s="console";
+    break;
   case GWEN_LoggerType_File:
-    s="file"; break;
+    s="file";
+    break;
   case GWEN_LoggerType_Syslog:
-    s="syslog"; break;
+    s="syslog";
+    break;
   case GWEN_LoggerType_Function:
-    s="function"; break;
+    s="function";
+    break;
   case GWEN_LoggerType_Unknown:
   default:
-    s="unknown"; break;
+    s="unknown";
+    break;
   } /* switch */
   return s;
 }
 
 
 
-int GWEN_Logger_Exists(const char *logDomain){
+int GWEN_Logger_Exists(const char *logDomain)
+{
   assert(logDomain);
   return (GWEN_LoggerDomain_Find(logDomain)!=0);
 }
