@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: gwentime.c 818 2005-08-04 04:55:48Z aquamaniac $
+    cvs         : $Id$
     begin       : Wed Mar 24 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -42,7 +42,8 @@
 
 
 
-int GWEN_Time__GetCurrentTime(GWEN_TIME *ti){
+int GWEN_Time__GetCurrentTime(GWEN_TIME *ti)
+{
   struct timezone tz;
   struct timeval tv;
 
