@@ -62,54 +62,69 @@ void GWEN_ConfigMgr_free(GWEN_CONFIGMGR *mgr);
 
 GWENHYWFAR_API
 int GWEN_ConfigMgr_GetGroup(GWEN_CONFIGMGR *mgr,
-			    const char *groupName,
-			    const char *subGroupName,
-			    GWEN_DB_NODE **pDb,
-			    uint32_t guiid);
+                            const char *groupName,
+                            const char *subGroupName,
+                            GWEN_DB_NODE **pDb);
 
 GWENHYWFAR_API
 int GWEN_ConfigMgr_SetGroup(GWEN_CONFIGMGR *mgr,
-			    const char *groupName,
-			    const char *subGroupName,
-			    GWEN_DB_NODE *db,
-			    uint32_t guiid);
+                            const char *groupName,
+                            const char *subGroupName,
+                            GWEN_DB_NODE *db);
+
+GWENHYWFAR_API
+int GWEN_ConfigMgr_HasGroup(GWEN_CONFIGMGR *mgr,
+                            const char *groupName,
+                            const char *subGroupName);
 
 GWENHYWFAR_API
 int GWEN_ConfigMgr_LockGroup(GWEN_CONFIGMGR *mgr,
-			     const char *groupName,
-			     const char *subGroupName,
-			     uint32_t guiid);
+                             const char *groupName,
+                             const char *subGroupName);
 
 GWENHYWFAR_API
 int GWEN_ConfigMgr_UnlockGroup(GWEN_CONFIGMGR *mgr,
-			       const char *groupName,
-			       const char *subGroupName,
-			       uint32_t guiid);
+                               const char *groupName,
+                               const char *subGroupName);
 
 GWENHYWFAR_API
 int GWEN_ConfigMgr_GetUniqueId(GWEN_CONFIGMGR *mgr,
-			       const char *groupName,
-			       char *buffer,
-			       uint32_t bufferLen,
-			       uint32_t guiid);
+                               const char *groupName,
+                               char *buffer,
+                               uint32_t bufferLen);
+
+/**
+ * Create an id which is unique inside the given group derived from
+ * the given id.
+ * @return 0 if okay, error code otherwise
+ * @param mgr pointer to config mgr object
+ * @param groupName name of the group within the id is unique
+ * @param doCheck if !=0 the derived unique id MUST NOT exist
+ * @param buffer buffer to receive the generated unique id
+ * @param bufferLen size of the buffer pointed to by "buffer" above
+ */
+GWENHYWFAR_API
+int GWEN_ConfigMgr_MkUniqueIdFromId(GWEN_CONFIGMGR *mgr,
+                                    const char *groupName,
+                                    uint32_t uid,
+                                    int doCheck,
+                                    char *buffer,
+                                    uint32_t bufferLen);
 
 GWENHYWFAR_API
 int GWEN_ConfigMgr_DeleteGroup(GWEN_CONFIGMGR *mgr,
-			       const char *groupName,
-			       const char *subGroupName,
-			       uint32_t guiid);
+                               const char *groupName,
+                               const char *subGroupName);
 
 
 GWENHYWFAR_API
 int GWEN_ConfigMgr_ListGroups(GWEN_CONFIGMGR *mgr,
-			      GWEN_STRINGLIST *sl,
-			      uint32_t guiid);
+                              GWEN_STRINGLIST *sl);
 
 GWENHYWFAR_API
 int GWEN_ConfigMgr_ListSubGroups(GWEN_CONFIGMGR *mgr,
-				 const char *groupName,
-				 GWEN_STRINGLIST *sl,
-				 uint32_t guiid);
+                                 const char *groupName,
+                                 GWEN_STRINGLIST *sl);
 
 
 #ifdef __cplusplus
